import pytest

from box_ai_agents_toolkit import authorize_app, get_oauth_client


@pytest.mark.skip
def test_box_authorize_app_tool():
    try:
        authorize_app()
    except Exception as e:
        assert str(e) == "Box application not authorized yet."


@pytest.mark.skip
def test_box_auth_client():
    try:
        get_oauth_client()
    except Exception as e:
        assert str(e) == "Box application not authorized yet."




from setuptools import setup, find_packages

setup(
    name="orange-mcp-server-box",
    version="0.1.0",
    description="Add your description here",
    author="orange",
    author_email="support@orange.ai",
    url="",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
    install_requires=['box-ai-agents-toolkit>=0.0.38', 'box-sdk-gen>=1.13.0', 'mcp[cli]>=1.6.0', 'python-dotenv>=1.1.0'],
    keywords=["orange"] + [],
)



from box_ai_agents_toolkit import (
    BoxClient,
    box_file_text_extract,
    box_file_download,
)


def test_box_api_read_basic(box_client: BoxClient):
    # HAB-1-01.docx = 1728677291168. This file must exists
    resp = box_file_text_extract(box_client, "1728677291168")
    assert resp is not None
    assert len(resp) > 0
    assert "HAB-1-01" in resp


def test_box_api_file_download(box_client: BoxClient):
    # HAB-1-01.docx = 1728677291168. This file must exists
    saved_path, file_content, mime_type = box_file_download(box_client, "1728677291168")

    assert saved_path is None
    assert file_content is not None
    assert mime_type is not None
    assert len(file_content) > 0
